@@ -21,7 +21,6 @@ import os
 import re
 from calculate.install.distr import DistributiveError, IsoDistributive
 from calculate.install.variables.kernel import KernelConfig
-from calculate.lib.utils.common import getValueFromCmdLine
 from calculate.lib.utils.dracut import Dracut
 from calculate.lib.utils.grub import GrubCommand
 from calculate.lib.utils.portage import getSquashList
@@ -790,10 +789,17 @@ class VariableClBuilderImageFilename(Variable):
         base_dn = self.Get('cl_builder_image_path')
 
         if build_id:
-            if self.Get('os_root_type_ext') in RootType.RebuildAvailable:
+            root_type_ext = self.Get('os_root_type_ext')
+            if root_type_ext in RootType.RebuildAvailable:
                 base_dn = self.Get('cl_builder_flash_repository')
                 addon_dn = base_dn.replace("/linux", "/iso")
                 return self._isoname(base_dn, rewrite=False, addon_dn=addon_dn)
+            elif root_type_ext in RootType.IsoScanGrub:
+                base_dn = self.Get('cl_builder_livemenu_path')
+                if not base_dn:
+                    raise VariableError(
+                        _("Failed to determine the isoscan path"))
+                return self._isoname(base_dn, rewrite=False)
             else:
                 return self._isoname(base_dn, rewrite=False)
         return ""
@@ -806,8 +812,11 @@ class VariableClBuilderIsoBasePath(Variable):
     default_value = "/var/calculate/tmp"
 
     def get(self):
-        if self.Get('os_root_type_ext') in RootType.RebuildAvailable:
+        root_type_ext = self.Get('os_root_type_ext')
+        if root_type_ext in RootType.RebuildAvailable:
             return path.join(self.Get('cl_builder_flash_path'), "tmp")
+        if root_type_ext in RootType.IsoScanGrub:
+            return path.join(self.Get('cl_isoscan_base_path'), "tmp")
         return self.default_value
 
 
@@ -1421,12 +1430,12 @@ class VariableClBuilderLivemenuPath(Variable):
         root_type_ext = self.Get('os_root_type_ext')
         if root_type_ext in RootType.LiveFlash:
             yield (Dracut.IsoLive, _("Boot Flash"))
-        elif root_type_ext in RootType.IsoScan:
+        elif root_type_ext in RootType.IsoScanFlash:
             yield (Dracut.IsoScanPath, _("Boot Flash"))
         elif root_type_ext in RootType.IsoScanGrub:
             grub_rep = self.get_isoscan_grub_repository()
             if grub_rep:
-                yield (Dracut.IsoScanPath, _("HDD Grub"))
+                yield (grub_rep, _("HDD Grub"))
         elif root_type_ext in RootType.Grubable:
             live_path = self.get_live_path()
             if live_path:
@@ -1534,17 +1543,12 @@ class VariableClBuilderFlashDev(ReadonlyVariable):
                 return ""
         return ""
 
-
 class VariableClBuilderFlashPath(ReadonlyVariable):
     """
     Путь, куда подключена flash (загрузка либо с флешки, либо с iso)
     """
 
     def get(self):
-        typemenu = self.Get('cl_builder_livemenu_type')
-        root_type_ext = self.Get('os_root_type_ext')
-        if root_type_ext in RootType.IsoScanGrub and typemenu == "grub":
-            return Dracut.IsoScanPath
         try:
             iso = self.Get('cl_builder_flash_dev')
             if iso:
@@ -1568,3 +1572,26 @@ class VariableClBuilderFlashUuid(ReadonlyVariable):
                     'install.os_disk_uuid',
                     install_os_disk_dev=dev, limit=1)
         return ""
+
+class VariableClBuilderGrubRefreshSet(ReadonlyVariable):
+    """
+    Обновить меню grub (HDD c включенным LiveHDD или isoscan-grub
+    """
+    def get(self):
+        root_type_ext = self.Get('os_root_type_ext')
+        action = self.Get('cl_action')
+        if action == Actions.Image:
+            if root_type_ext in RootType.HDDs:
+                rep_dir = self.Get('cl_livemenu_path')
+                if rep_dir:
+                    isoimage = self.Get('cl_builder_image_filename')
+                    isoimage_dir = path.dirname(isoimage)
+                    if isoimage_dir == rep_dir:
+                        return "on"
+            elif root_type_ext in RootType.IsoScanGrub:
+                isoimage = self.Get('cl_builder_image_filename')
+                rep_dir = self.Get('cl_builder_livemenu_path')
+                isoimage_dir = path.dirname(isoimage)
+                if isoimage_dir == rep_dir:
+                    return "on"
+        return "off"
